@@ -1,3 +1,5 @@
+import sys
+
 import click
 
 from strawberry import Schema
@@ -7,7 +9,20 @@ from strawberry.utils.importer import import_module_symbol
 
 @click.command(short_help="Exports the schema")
 @click.argument("schema", type=str)
-def export_schema(schema: str):
+@click.option(
+    "--app-dir",
+    default=".",
+    type=str,
+    show_default=True,
+    help=(
+        "Look for the module in the specified directory, by adding this to the "
+        "PYTHONPATH. Defaults to the current working directory. "
+        "Works the same as `--app-dir` in uvicorn."
+    ),
+)
+def export_schema(schema: str, app_dir):
+    sys.path.insert(0, app_dir)
+
     try:
         schema_symbol = import_module_symbol(schema, default_symbol_name="schema")
     except (ImportError, AttributeError) as exc:
