@@ -169,3 +169,10 @@ class MissingQueryError(Exception):
         message = 'Request data is missing a "query" value'
 
         super().__init__(message)
+
+
+class InvalidFieldArgument(Exception):
+    def __init__(self, field_name: str, argument_name: str, argument_type: str):
+        message = f'Argument "{argument_name}" on field "{field_name}" cannot be of type\
+            "{argument_type}"'
+        super().__init__(message)
