@@ -1,6 +1,6 @@
 from .error_type import error_type
 from .exceptions import UnregisteredTypeException
-from .type import input, type
+from .object_type import input, type
 
 
 __all__ = ["error_type", "UnregisteredTypeException", "input", "type"]
