@@ -1,12 +1,12 @@
 import dataclasses
-from functools import partial
 from typing import List, Optional, Type, cast
 
 from .exceptions import MissingFieldAnnotationError, MissingReturnAnnotationError
-from .field import StrawberryField
+from .field import StrawberryField, field
 from .types.type_resolver import _get_fields
 from .types.types import FederationTypeParams, TypeDefinition
 from .utils.str_converters import to_camel_case
+from .utils.typing import __dataclass_transform__
 
 
 def _get_interfaces(cls: Type) -> List[TypeDefinition]:
@@ -38,29 +38,29 @@ def _check_field_annotations(cls: Type):
     cls_annotations = cls.__dict__.get("__annotations__", {})
     cls.__annotations__ = cls_annotations
 
-    for field_name, field in cls.__dict__.items():
-        if not isinstance(field, (StrawberryField, dataclasses.Field)):
+    for field_name, field_ in cls.__dict__.items():
+        if not isinstance(field_, (StrawberryField, dataclasses.Field)):
             # Not a dataclasses.Field, nor a StrawberryField. Ignore
             continue
 
         # If the field is a StrawberryField we need to do a bit of extra work
         # to make sure dataclasses.dataclass is ready for it
-        if isinstance(field, StrawberryField):
+        if isinstance(field_, StrawberryField):
 
             # Make sure the cls has an annotation
             if field_name not in cls_annotations:
                 # If the field uses the default resolver, the field _must_ be
                 # annotated
-                if not field.base_resolver:
+                if not field_.base_resolver:
                     raise MissingFieldAnnotationError(field_name)
 
                 # The resolver _must_ have a return type annotation
                 # TODO: Maybe check this immediately when adding resolver to
                 #       field
-                if field.base_resolver.type_annotation is None:
+                if field_.base_resolver.type_annotation is None:
                     raise MissingReturnAnnotationError(field_name)
 
-                cls_annotations[field_name] = field.base_resolver.type_annotation
+                cls_annotations[field_name] = field_.base_resolver.type_annotation
 
             # TODO: Make sure the cls annotation agrees with the field's type
             # >>> if cls_annotations[field_name] != field.base_resolver.type:
@@ -115,13 +115,14 @@ def _process_type(
     # so we need to restore them, this will change in future, but for now this
     # solution should suffice
 
-    for field in fields:
-        if field.base_resolver and field.python_name:
-            setattr(cls, field.python_name, field.base_resolver.wrapped_func)
+    for field_ in fields:
+        if field_.base_resolver and field_.python_name:
+            setattr(cls, field_.python_name, field_.base_resolver.wrapped_func)
 
     return cls
 
 
+@__dataclass_transform__(order_default=True, field_descriptors=(field, StrawberryField))
 def type(
     cls: Type = None,
     *,
@@ -158,8 +159,48 @@ def type(
     return wrap(cls)
 
 
-input = partial(type, is_input=True)
-interface = partial(type, is_interface=True)
+@__dataclass_transform__(order_default=True, field_descriptors=(field, StrawberryField))
+def input(
+    cls: Type = None,
+    *,
+    name: str = None,
+    description: str = None,
+    federation: Optional[FederationTypeParams] = None,
+):
+    """Annotates a class as a GraphQL Input type.
+    Example usage:
+    >>> @strawberry.input:
+    >>> class X:
+    >>>     field_abc: str = "ABC"
+    """
+
+    return type(
+        cls, name=name, description=description, federation=federation, is_input=True
+    )
+
+
+@__dataclass_transform__(order_default=True, field_descriptors=(field, StrawberryField))
+def interface(
+    cls: Type = None,
+    *,
+    name: str = None,
+    description: str = None,
+    federation: Optional[FederationTypeParams] = None,
+):
+    """Annotates a class as a GraphQL Interface.
+    Example usage:
+    >>> @strawberry.interface:
+    >>> class X:
+    >>>     field_abc: str
+    """
+
+    return type(
+        cls,
+        name=name,
+        description=description,
+        federation=federation,
+        is_interface=True,
+    )
 
 
 __all__ = [
